aboutsummaryrefslogtreecommitdiff
path: root/gdb/tui/tui-file.h
diff options
context:
space:
mode:
Diffstat (limited to 'gdb/tui/tui-file.h')
-rw-r--r--gdb/tui/tui-file.h18
1 files changed, 13 insertions, 5 deletions
diff --git a/gdb/tui/tui-file.h b/gdb/tui/tui-file.h
index 0e90cdf..aceaab6 100644
--- a/gdb/tui/tui-file.h
+++ b/gdb/tui/tui-file.h
@@ -1,4 +1,4 @@
/* UI_FILE - a generic STDIO like output stream.
Copyright (C) 1999-2017 Free Software Foundation, Inc.
This file is part of GDB.
@@ -19,9 +19,17 @@
#ifndef TUI_FILE_H
#define TUI_FILE_H
-extern struct ui_file *tui_fileopen (FILE *);
-extern struct ui_file *tui_sfileopen (int);
-extern char *tui_file_get_strbuf (struct ui_file *);
-extern void tui_file_adjust_strbuf (int, struct ui_file *);
+#include "ui-file.h"
+
+/* A STDIO-like output stream for the TUI. */
+
+class tui_file : public stdio_file
+{
+public:
+ explicit tui_file (FILE *stream);
+
+ void flush () override;
+ void puts (const char *) override;
+};
#endif
@@ -1,4 +1,4 @@
-/* UI_FILE - a generic STDIO like output stream.
+/* TUI_FILE - a STDIO-like output stream for the TUI.
Copyright (C) 1999-2017 Free Software Foundation, Inc.
This file is part of GDB.